Welcome to Freezer Client Release Notes documentation!
======================================================

Contents
========

.. toctree::
   :maxdepth: 2

   unreleased
   ussuri
   stein
   queens
   pike
   ocata
   newton

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`